@@ -1,6 +1,6 @@
 package CHI::Driver;
 BEGIN {
-  $CHI::Driver::VERSION = '0.47';
+  $CHI::Driver::VERSION = '0.48';
 }
 use Carp;
 use CHI::CacheObject;
@@ -283,7 +283,18 @@ sub set {
                 $options = { expires_in => $options };
             }
         }
-        $options = { %{ $self->_default_set_options }, %$options };
+
+        # Disregard default expires_at and expires_in if either are provided
+        #
+        if (   exists( $options->{expires_at} )
+            || exists( $options->{expires_in} ) )
+        {
+            $options =
+              { expires_variance => $self->expires_variance, %$options };
+        }
+        else {
+            $options = { %{ $self->_default_set_options }, %$options };
+        }
     }
 
     $self->set_with_options( $key, $value, $options );
@@ -686,7 +697,7 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.47
+version 0.48
 
 =head1 DESCRIPTION
 
